pub struct CoreDumpsDisabledGuard {}Expand description
RAII guard that disables core dumps on macOS and restores the previous RLIMIT_CORE on drop.
On non-macOS platforms, this type is still defined to keep cross-platform signatures consistent, but creating it is not possible via this crate’s API.